#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Do something for uninstalling hmigration."""

import os

import iobase.xmldata as xmldata
import iobase.cmdexec as cmdexec
import ionas.request as request
from product_conf import (LIBEXEC_DIR, STOR_IF_TO_VOL, )
from product_conf.devinfo import (VOL_INFO, )
from fal_info import (FAL_VOLCTRL_PATH, Results, ReqTypes)


INTERNAL_VOL = STOR_IF_TO_VOL["internal"][1]
MANUAL_PATH = os.path.join(VOL_INFO[INTERNAL_VOL]["mnt_point"],
                            VOL_INFO[INTERNAL_VOL]["share_root"],
                            "LAN DISK Manual",
                            "H_XR_XV移行パッケージ_画面で見るマニュアル.pdf")

UNMOUNT_EVENT_XML = '<events><eventinfo category="volume" ' + \
                                'action="unmount" previous="true">' + \
                    '<volume><name>' + INTERNAL_VOL + '</name></volume>' + \
                    '</eventinfo></events>'

VOLUME_QUERY_REQ_XML_TMPL = \
    '<volctrl><volume><name type="volume">%s</name></volume></volctrl>'

VOLUME_STATUS_PATH = "volume/status"
STATUS_MOUNTED = "mounted"


def __send_request(target, type, body=""):
    """Send request entry to "target"."""

    entry = request.Entry(type, body)
    return request.Request(target).request(entry).get_entry()


def is_volume_mounted(vol):
    """Check if "vol" is mounted."""

    result_entry = __send_request(FAL_VOLCTRL_PATH, ReqTypes.QUERY,
                            VOLUME_QUERY_REQ_XML_TMPL % (vol,))

    if (result_entry.get_result() == Results.OK and
        result_entry.get().get_value(VOLUME_STATUS_PATH) == STATUS_MOUNTED):

        return True

    return False


def uninstall_manual():
    """Uninstall manual for the fxwf package by a event handler."""

    if os.path.exists(MANUAL_PATH):
        os.unlink(MANUAL_PATH)


#
# Main
#

if is_volume_mounted(INTERNAL_VOL):
    uninstall_manual()
